@@ -1,4 +1,4 @@
-from scripts.bigdirs import bigdirs
+from scripts.bigdirs import bigdirs, process_bigdirs
 from scripts.dedupe import deduplicate_db
 from scripts.invalid_paths import rename_invalid_paths
 from scripts.merge_dbs import merge_dbs
