@@ -41,16 +41,16 @@ def usage(action) -> str:
         library {action} --sibling   # only include files which have more than or equal to one sibling
         library {action} --solo      # only include files which are alone by themselves
 
-        The value of this constraint is configurable via the `--lower` flag
+        `--sibling` is just a shortcut for `--lower 2`; `--solo` is `--upper 1`
+        library {action} --sibling --solo      # you will always get zero records here
+        library {action} --lower 2 --upper 1   # equivalent
+
+        You can be more specific via the `--upper` and `--lower` flags
         library {action} --lower 3   # only include files which have three or more siblings
         library {action} --upper 3   # only include files which have fewer than three siblings
         library {action} --lower 3 --upper 3   # only include files which are three siblings inclusive
         library {action} --lower 12 --upper 25 -OOO  # on my machine this launches My Mister 2018
 
-        `--sibling` is just a shortcut for `--lower 2`; `--solo` is `--upper 1`
-        library {action} --sibling --solo      # you will always get zero records here
-        library {action} --lower 2 --upper 1   # equivalent
-
     Play recent partially-watched videos (requires mpv history):
         library {action} --partial       # play newest first
         library {action} --partial old   # play oldest first
@@ -74,7 +74,7 @@ def usage(action) -> str:
         library {action} -p    # print in a table
         library {action} -p p  # equivalent
         library {action} -p a  # print an aggregate report
-        library {action} -p a  # print a bigdirs report (see lb bigdirs -h for more info)
+        library {action} -p b  # print a bigdirs report (see lb bigdirs -h for more info)
         library {action} -p f  # print fields -- useful for piping paths to utilities like xargs or GNU Parallel
 
         Check if you have downloaded something before
@@ -256,6 +256,7 @@ def parse_args_sort(args):
         subtitle_count = "=0"
 
     sorts = [
+        (getattr(args, "random", False), "random", "random"),
         (args.sort and "rank" in args.sort, args.sort, args.sort),
         ("video_count" in m_columns and args.action == SC.watch, "video_count > 0 desc", "video_count > 0 "),
         ("audio_count" in m_columns, "audio_count > 0 desc", "audio_count > 0"),
@@ -295,7 +296,11 @@ def parse_args_sort(args):
         (True, "random", "random"),
     ]
 
-    sort = [c[2] if args.print else c[1] for c in sorts if c[0]]
+    sort = [
+        c[2] if args.print and "f" not in args.print and "limit" in getattr(args, "defaults", []) else c[1]
+        for c in sorts
+        if c[0]
+    ]
     sort = list(filter(bool, sort))
     sort = [override_sort(s) for s in sort]
     sort = "\n        , ".join(sort)
@@ -538,10 +543,12 @@ def construct_query(args) -> Tuple[str, dict]:
             limit = consts.DEFAULT_PLAY_QUEUE * 16
 
         if "limit" in args.defaults:
-            cf.append(f"and m.rowid in (select rowid from media order by random() limit {limit})")
-    else:
-        if args.random:
-            args.sort = "random(), " + args.sort
+            where_not_deleted = (
+                "where COALESCE(time_deleted,0) = 0"
+                if "time_deleted" in m_columns and "time_deleted" not in " ".join(sys.argv)
+                else ""
+            )
+            cf.append(f"and m.rowid in (select rowid from media {where_not_deleted} order by random() limit {limit})")
 
     args.sql_filter = " ".join(cf)
     args.sql_filter_bindings = bindings
@@ -563,7 +570,7 @@ def construct_query(args) -> Tuple[str, dict]:
         {'AND (score IS NULL OR score > 7)' if 'score' in m_columns else ''}
         {'AND (upvote_ratio IS NULL OR upvote_ratio > 0.73)' if 'upvote_ratio' in m_columns else ''}
         {'AND COALESCE(time_downloaded,0) = 0' if args.online_media_only else ''}
-        {'AND time_downloaded > 0 AND path not like "http%"' if args.local_media_only else ''}
+        {'AND COALESCE(time_downloaded,1)!= 0 AND path not like "http%"' if args.local_media_only else ''}
     )
     SELECT
         {SELECT}
@@ -693,6 +700,7 @@ def process_playqueue(args) -> None:
             args.play_in_order == 0,
             "sort" in args.defaults,
             not args.partial,
+            not args.random,
         ]
     ):
         media = utils.mpv_enrich(args, media)
